#' A programmatic R interface the Orcid.org API.
#' 
#' @importFrom httr GET content stop_for_status accept
#' @importFrom jsonlite fromJSON
#' @name rorcid-package
#' @docType package
#' @author Scott Chamberlain \email{myrmecocystus@@gmail.com}
#' @keywords package
NULL


#' Lookup-table for search fields
#' @name fields
#' @docType data
#' @keywords data
NULL

#' Defunct functions in rorcid
#'
#' \itemize{
#'  \item \code{\link{summary.or_cid}}: Function is gone. Deemed not really 
#'  that useful, and hard to maintain given other changes in the package.
#' }
#'
#' @name rorcid-defunct
NULL
